document.addEventListener('DOMContentLoaded', () => {
  const gallery = document.querySelector('.gallery');
  const viewToggle = document.querySelector('.view-toggle');
  
  // View toggle functionality
  viewToggle.addEventListener('click', () => {
    gallery.classList.toggle('list-view');
  });
  
  // Lazy loading images with animation
  const images = document.querySelectorAll('.gallery-item img');
  
  const imageObserver = new IntersectionObserver((entries, observer) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        const img = entry.target;
        img.style.opacity = '0';
        img.src = img.getAttribute('src');
        
        img.onload = () => {
          img.style.transition = 'opacity 0.5s ease-in-out';
          img.style.opacity = '1';
        };
        
        observer.unobserve(img);
      }
    });
  });
  
  images.forEach(img => imageObserver.observe(img));
  
  // Add touch support for mobile devices
  let touchStartY;
  
  gallery.addEventListener('touchstart', (e) => {
    touchStartY = e.touches[0].clientY;
  });
  
  gallery.addEventListener('touchmove', (e) => {
    if (!touchStartY) return;
    
    const touchEndY = e.touches[0].clientY;
    const diff = touchStartY - touchEndY;
    
    if (Math.abs(diff) > 50) {
      gallery.style.transform = `translateY(${-diff}px)`;
    }
  });
  
  gallery.addEventListener('touchend', () => {
    gallery.style.transform = '';
    touchStartY = null;
  });
});